/*  $Id: ChainedErrHandler.java 1220 2011-09-11 14:03:19Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2010 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;

/**
 * Handle error with two chained error handler.
 * One is "main", the other is the next to be chained. 
 * handle() methods of both handlers are invoke in sequence from
 * the same thread : the one call ChainedErrHandler.handle().
 * First , main.handle(), then chained.handle(). So beware when handle()
 * is to long from main or chained.
 * @version $Id: ChainedErrHandler.java 1220 2011-09-11 14:03:19Z sdevaux $
 * @author Sebastien Devaux
 */
public class ChainedErrHandler implements ErrorHandler {
    /**
     * Create new chained error handler.
     * @param main first error handler.
     * @param chained next error handler (may be itself a ChainedErrorHandler...).
     */
    public ChainedErrHandler(ErrorHandler main,ErrorHandler chained) {
        _main=main;
        _chained=chained;
    }
    // Error handler implementation
    public void handle(Error e) {
        _main.handle(e);
        _chained.handle(e);
    }
    // Error handler implementation
    public boolean checkOnly() {
        return _main.checkOnly();
    }
    public boolean checkAndReset() {
    	boolean res=_main.checkAndReset();
    	_chained.checkAndReset();
    	return res;
    }
    /** main error handler. The first to handle errors. */
    private ErrorHandler _main;
    /** chained error handler. The second to handle errors, no matters
        how the first handles errors. */
    private ErrorHandler _chained;
}
